part of 'password_reset_bloc.dart';

abstract class PasswordResetState extends Equatable {
  const PasswordResetState();

  @override
  List<Object> get props => [];
}

class PasswordResetInitial extends PasswordResetState {
  const PasswordResetInitial();
}

class PasswordResetLoading extends PasswordResetState {
  const PasswordResetLoading();
}

class PasswordResetError extends PasswordResetState {
  final String message;
  const PasswordResetError({required this.message});

  @override
  List<Object> get props => [message];
}

class PasswordResetReady extends PasswordResetState {
  const PasswordResetReady();
}

class PasswordResetFinished extends PasswordResetState {
  const PasswordResetFinished();
}
